@@ -17,6 +17,7 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *)
 
+open Int64ops
 open BasicSocket
 open Printf2
 open CommonGlobals
@@ -59,7 +60,11 @@ let search_find num = Hashtbl.find searches_by_num num
 let search_add_result_in s r =
   try
     let (c,_) = Intmap.find r.stored_result_num s.search_results in
-    incr c
+    incr c;
+
+    let ri = IndexedResults.get_result r in 
+    if ri.result_modified then
+      List.iter (fun f -> f r) s.op_search_new_result_handlers
   with _ ->
       s.search_results <- Intmap.add r.stored_result_num (ref 1, r)
       s.search_results;
@@ -274,7 +279,7 @@ let custom_query buf query =
           " label (if default = "" then "" else
             try
               let size = Int64.of_string default in
-              let size = Int64.div size (Int64.of_int 1048576) in
+              let size = size // 1048576L in
               Int64.to_string size
             with _ -> "")
       
@@ -298,7 +303,7 @@ let custom_query buf query =
           " label (if default = "" then "" else
             try
               let size = Int64.of_string default in
-              let size = Int64.div size (Int64.of_int 1048576) in
+              let size = size // 1048576L in
               Int64.to_string size
             with _ -> "")
       
