@@ -233,8 +233,8 @@ let parse (s_out : string) (s_in : string) =
       let ciphers = {
           in_cipher = create_cipher ();
           out_cipher = create_cipher ();
-          in_xinu = Int64.of_int 0x51;
-          out_xinu = Int64.of_int 0x51;
+          in_xinu = 0x51L;
+          out_xinu = 0x51L;
         } in
       begin
         try
@@ -667,8 +667,6 @@ let parse_netname c =
   let rec iter pos =
     if pos < len then
       if s.[pos] = '\000' then begin
-          let netname = String.sub s start_pos (pos-start_pos) in
-(*          lprintf "netname: [%s]\n" (String.escaped netname);*)
           c.c_pos <- pos + 1;
           c.c_parser <- parse_packets;
           parse_packets c
@@ -687,8 +685,8 @@ let received ip port time s =
         let ciphers = {
             in_cipher = create_cipher ();
             out_cipher = create_cipher ();
-            in_xinu = Int64.of_int 0x51;
-            out_xinu = Int64.of_int 0x51;
+            in_xinu = 0x51L;
+            out_xinu = 0x51L;
           } in
         let c = {
             c_ip = ip;
